@@ -1,7 +1,7 @@
 // qxgeditMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1909,15 +1909,15 @@ void qxgeditMainForm::viewOptions (void)
 void qxgeditMainForm::helpAbout (void)
 {
 	// Stuff the about box text...
-	QString sText = "<p>\n";
-	sText += "<b>" QXGEDIT_TITLE " - " + tr(QXGEDIT_SUBTITLE) + "</b><br />\n";
+	QString sText = "<h1>" QXGEDIT_TITLE "</h1>\n";
+	sText += "<p>" + tr(QXGEDIT_SUBTITLE) + "<br />\n";
 	sText += "<br />\n";
 	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
 //	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
 #ifdef CONFIG_DEBUG
 	sText += "<small><font color=\"red\">";
 	sText += tr("Debugging option enabled.");
-	sText += "</font></small><br />\n";
+	sText += "</font></small>\n";
 #endif
 	sText += "<br />\n";
 	sText += tr("Using: Qt %1").arg(qVersion());
@@ -2362,9 +2362,27 @@ void qxgeditMainForm::drumsetupNoteComboActivated ( int iNote )
 {
 	if (m_pMasterMap) {
 		const int iDrumset = m_ui.DrumsetupCombo->currentIndex();
-		const unsigned short key = (unsigned short) (iDrumset << 7)
-			+ m_ui.DrumsetupNoteCombo->itemData(iNote).toUInt();
+		const unsigned short drum_key
+			= m_ui.DrumsetupNoteCombo->itemData(iNote).toUInt();
+		const unsigned short key
+			= (unsigned short) (iDrumset << 7) + drum_key;
 		m_pMasterMap->DRUMSETUP.set_current_key(key);
+		// Update drum voice/key defaults...
+		const int iDrumKit
+			= m_ui.DrumsetupVoiceCombo->currentIndex();
+		XGDrumKit drumkit(iDrumKit);
+		if (drumkit.item()) {
+			const int i = drumkit.find_voice(drum_key);
+			if (i >= 0) {
+				const XGDrumVoice drum(&drumkit, i);
+				m_ui.DrumsetupLevelDial->setValue(drum.level());
+				m_ui.DrumsetupGroupDial->setValue(drum.group());
+				m_ui.DrumsetupPanDial->setValue(drum.pan());
+				m_ui.DrumsetupReverbDial->setValue(drum.reverb());
+				m_ui.DrumsetupChorusDial->setValue(drum.chorus());
+				m_ui.DrumsetupNoteOffCheck->setValue(drum.noteOff());
+			}
+		}
 	}
 }
 
